==> haskell-these-1.2-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 these
version:              1.2
visibility:           public
id:                   these-1.2-Fwv95j4CO3uLLOFstb6FOv
key:                  these-1.2-Fwv95j4CO3uLLOFstb6FOv
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  3fca1dec9bb737fb19dfba9dc195423c
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.4.8/site-local/these-1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/these-1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/these-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.2-Fwv95j4CO3uLLOFstb6FOv
depends:
    assoc-1.1.1-ECHUyXuI4DU7saXDIs2gf3 base-4.17.2.1 binary-0.8.9.1
    deepseq-1.4.8.0 foldable1-classes-compat-0.1-JBZFUBdAteCQ0cZwfyclx
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-these-1.2-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 these
version:              1.2
visibility:           public
id:                   these-1.2-FFAsNcaot3MEtMVxUY5dCC
key:                  these-1.2-FFAsNcaot3MEtMVxUY5dCC
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  a1eb0ef9080cfac1effff78f30342d3b
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.4.8/site-local/these-1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/these-1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/these-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.2-FFAsNcaot3MEtMVxUY5dCC
depends:
    assoc-1.1.1-ECHUyXuI4DU7saXDIs2gf3 base-4.17.2.1 binary-0.8.9.1
    deepseq-1.4.8.0 foldable1-classes-compat-0.1-3cFJnmZwi91CKyudsARBTK
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
